@@ -16,7 +16,7 @@
 #' @export
 
 
-Lwls1D <- function( bw, kernel_type, win, xin, yin, xout, npoly = 1L, nder = 0L){
+Lwls1D <- function( bw, kernel_type, win=rep(1L, length(xin)), xin, yin, xout, npoly = 1L, nder = 0L){
 
   if(is.unsorted(xout)){
     stop('`xout` needs to be sorted in increasing order')
